==> nxcomp-1.3.2-4.tar.gz: nxcomp/Jpeg.h <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001,2003 NoMachine, http://www.nomachine.com.           */
/*                                                                        */
/* NXPROXY, NX protocol compression and NX extensions to this software    */
/* are copyright of NoMachine. Redistribution and use of the present      */
/* software is allowed according to terms specified in the file LICENSE   */
/* which comes in the source distribution.                                */
/*                                                                        */
/* Check http://www.nomachine.com/licensing.html for applicability.       */
/*                                                                        */
/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/**************************************************************************/

#ifndef Jpeg_H
#define Jpeg_H

#include "Misc.h"

#include "Unpack.h"

int UnpackJpeg(T_geometry *geometry, unsigned char method,
                   unsigned char *src_data, int src_size, int dst_bpp,
                       int dst_width, int dst_height, unsigned char *dst_data,
                           int dst_size);

#endif /* Jpeg_H */

==> nxcomp-2.0.0-81.tar.gz: nxcomp/Jpeg.h <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
/*                                                                        */
/* NXPROXY, NX protocol compression and NX extensions to this software    */
/* are copyright of NoMachine. Redistribution and use of the present      */
/* software is allowed according to terms specified in the file LICENSE   */
/* which comes in the source distribution.                                */
/*                                                                        */
/* Check http://www.nomachine.com/licensing.html for applicability.       */
/*                                                                        */
/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/**************************************************************************/

#ifndef Jpeg_H
#define Jpeg_H

#include "Misc.h"
#include "Unpack.h"

int UnpackJpeg(T_geometry *geometry, unsigned char method,
                   unsigned char *srcData, int srcSize, int dstBpp,
                       int dstWidth, int dstHeight, unsigned char *dstData,
                           int dstSize, int byteOrder);

#endif /* Jpeg_H */
